#include <windows.h>
#include "util_121.h"

extern void WinDestroyMenu (HMENU menu);

/*	Install the cross call procedures in the gCrossCallProcedureTable of cCrossCall_121.
*/
extern void InstallCrossCallMenus ();
